@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -40,7 +40,7 @@ void AttachmentVcardFromAddressBookJobTest::testAttachmentVCardWithInvalidItem()
     MessageComposer::AttachmentVcardFromAddressBookJob *job = new MessageComposer::AttachmentVcardFromAddressBookJob(item);
     QVERIFY(!job->exec());
     delete job;
-    job = Q_NULLPTR;
+    job = nullptr;
 }
 
 void AttachmentVcardFromAddressBookJobTest::testAttachmentVCardWithValidItem()
@@ -56,7 +56,7 @@ void AttachmentVcardFromAddressBookJobTest::testAttachmentVCardWithValidItem()
 
     MessageCore::AttachmentPart::Ptr part = job->attachmentPart();
     delete job;
-    job = Q_NULLPTR;
+    job = nullptr;
 
     QVERIFY(!part->data().isEmpty());
     QCOMPARE(part->mimeType(), QByteArray("text/x-vcard"));
@@ -73,7 +73,7 @@ void AttachmentVcardFromAddressBookJobTest::testAttachmentVCardWithInvalidVCard(
     MessageComposer::AttachmentVcardFromAddressBookJob *job = new MessageComposer::AttachmentVcardFromAddressBookJob(item);
     QVERIFY(!job->exec());
     delete job;
-    job = Q_NULLPTR;
+    job = nullptr;
 }
 
 void AttachmentVcardFromAddressBookJobTest::testAttachmentVCardWithEmptyVCard()
@@ -85,7 +85,7 @@ void AttachmentVcardFromAddressBookJobTest::testAttachmentVCardWithEmptyVCard()
     MessageComposer::AttachmentVcardFromAddressBookJob *job = new MessageComposer::AttachmentVcardFromAddressBookJob(item);
     QVERIFY(!job->exec());
     delete job;
-    job = Q_NULLPTR;
+    job = nullptr;
 }
 
 QTEST_MAIN(AttachmentVcardFromAddressBookJobTest)
