@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -36,7 +36,7 @@ class MessageComposer::RichTextComposerNgPrivate
 {
 public:
     RichTextComposerNgPrivate(RichTextComposerNg *q)
-        : autoCorrection(Q_NULLPTR),
+        : autoCorrection(nullptr),
           richtextComposer(q)
     {
         richTextComposerSignatures = new MessageComposer::RichTextComposerSignatures(richtextComposer, richtextComposer);
@@ -409,6 +409,5 @@ void RichTextComposerNg::forceAutoCorrection(bool selectedText)
             cur.setPosition(initialPosition);
             setTextCursor(cur);
         }
-
     }
 }
