@@ -17,6 +17,7 @@
 */
 
 #include "pane.h"
+#include "helper_p.h"
 
 #include <KActionCollection>
 #include <KActionMenu>
@@ -43,6 +44,7 @@
 #include "core/manager.h"
 #include <Akonadi/KMime/MessageStatus>
 #include "core/model.h"
+#include "messagelistutil_p.h"
 
 namespace MessageList
 {
@@ -52,18 +54,18 @@ class Q_DECL_HIDDEN Pane::Private
 public:
     Private(Pane *owner)
         : q(owner),
-          mXmlGuiClient(Q_NULLPTR),
-          mActionMenu(Q_NULLPTR),
-          mModel(Q_NULLPTR),
-          mSelectionModel(Q_NULLPTR),
+          mXmlGuiClient(nullptr),
+          mActionMenu(nullptr),
+          mModel(nullptr),
+          mSelectionModel(nullptr),
           mPreSelectionMode(Core::PreSelectLastSelected),
-          mNewTabButton(Q_NULLPTR),
-          mCloseTabButton(Q_NULLPTR),
-          mCloseTabAction(Q_NULLPTR),
-          mActivateNextTabAction(Q_NULLPTR),
-          mActivatePreviousTabAction(Q_NULLPTR),
-          mMoveTabLeftAction(Q_NULLPTR),
-          mMoveTabRightAction(Q_NULLPTR),
+          mNewTabButton(nullptr),
+          mCloseTabButton(nullptr),
+          mCloseTabAction(nullptr),
+          mActivateNextTabAction(nullptr),
+          mActivatePreviousTabAction(nullptr),
+          mMoveTabLeftAction(nullptr),
+          mMoveTabRightAction(nullptr),
           mPreferEmptyTab(false),
           mMaxTabCreated(0)
     { }
@@ -479,7 +481,7 @@ void Pane::Private::onSelectionChanged(const QItemSelection &selected, const QIt
     QString label;
     QIcon icon;
     QString toolTip;
-    foreach (const QModelIndex &index, s->selectedRows()) {
+    for (const QModelIndex &index : s->selectedRows()) {
         label += index.data(Qt::DisplayRole).toString() + QLatin1String(", ");
     }
     label.chop(2);
@@ -780,7 +782,7 @@ QItemSelection Pane::Private::mapSelectionToSource(const QItemSelection &selecti
 {
     QItemSelection result = selection;
 
-    foreach (const QAbstractProxyModel *proxy, mProxyStack) {
+    for (const QAbstractProxyModel *proxy : qAsConst(mProxyStack)) {
         result = proxy->mapSelectionToSource(result);
     }
 
@@ -808,7 +810,7 @@ void Pane::Private::updateTabControls()
         q->setCornerWidget(mCloseTabButton, Qt::TopRightCorner);
         mCloseTabButton->setVisible(true);
     } else {
-        q->setCornerWidget(Q_NULLPTR, Qt::TopRightCorner);
+        q->setCornerWidget(nullptr, Qt::TopRightCorner);
     }
     if (mCloseTabAction) {
         mCloseTabAction->setEnabled(enableAction);
@@ -831,7 +833,7 @@ void Pane::Private::updateTabControls()
         q->setCornerWidget(mNewTabButton, Qt::TopLeftCorner);
         mNewTabButton->setVisible(true);
     } else {
-        q->setCornerWidget(Q_NULLPTR, Qt::TopLeftCorner);
+        q->setCornerWidget(nullptr, Qt::TopLeftCorner);
     }
 
     q->setTabsClosable(true);
@@ -847,7 +849,7 @@ Item Pane::currentItem() const
 {
     Widget *w = static_cast<Widget *>(currentWidget());
 
-    if (w == Q_NULLPTR) {
+    if (w == nullptr) {
         return Item();
     }
 
@@ -858,7 +860,7 @@ KMime::Message::Ptr Pane::currentMessage() const
 {
     Widget *w = static_cast<Widget *>(currentWidget());
 
-    if (w == Q_NULLPTR) {
+    if (w == nullptr) {
         return KMime::Message::Ptr();
     }
 
@@ -868,7 +870,7 @@ KMime::Message::Ptr Pane::currentMessage() const
 QList<KMime::Message::Ptr > Pane::selectionAsMessageList(bool includeCollapsedChildren) const
 {
     Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == Q_NULLPTR) {
+    if (w == nullptr) {
         return QList<KMime::Message::Ptr>();
     }
     return w->selectionAsMessageList(includeCollapsedChildren);
@@ -877,7 +879,7 @@ QList<KMime::Message::Ptr > Pane::selectionAsMessageList(bool includeCollapsedCh
 Akonadi::Item::List Pane::selectionAsMessageItemList(bool includeCollapsedChildren) const
 {
     Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == Q_NULLPTR) {
+    if (w == nullptr) {
         return Akonadi::Item::List();
     }
     return w->selectionAsMessageItemList(includeCollapsedChildren);
@@ -886,7 +888,7 @@ Akonadi::Item::List Pane::selectionAsMessageItemList(bool includeCollapsedChildr
 QList<Akonadi::Item::Id> Pane::selectionAsListMessageId(bool includeCollapsedChildren) const
 {
     Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == Q_NULLPTR) {
+    if (w == nullptr) {
         return QList<Akonadi::Item::Id>();
     }
     return w->selectionAsListMessageId(includeCollapsedChildren);
@@ -895,7 +897,7 @@ QList<Akonadi::Item::Id> Pane::selectionAsListMessageId(bool includeCollapsedChi
 QVector<qlonglong> Pane::selectionAsMessageItemListId(bool includeCollapsedChildren) const
 {
     Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == Q_NULLPTR) {
+    if (w == nullptr) {
         return QVector<qlonglong>();
     }
     return w->selectionAsMessageItemListId(includeCollapsedChildren);
@@ -904,7 +906,7 @@ QVector<qlonglong> Pane::selectionAsMessageItemListId(bool includeCollapsedChild
 Akonadi::Item::List Pane::currentThreadAsMessageList() const
 {
     Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == Q_NULLPTR) {
+    if (w == nullptr) {
         return Akonadi::Item::List();
     }
     return w->currentThreadAsMessageList();
@@ -938,7 +940,7 @@ void Pane::markMessageItemsAsAboutToBeRemoved(MessageList::Core::MessageItemSetR
 QList<Akonadi::MessageStatus> Pane::currentFilterStatus() const
 {
     Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == Q_NULLPTR) {
+    if (w == nullptr) {
         return QList<Akonadi::MessageStatus>();
     }
     return w->currentFilterStatus();
@@ -947,7 +949,7 @@ QList<Akonadi::MessageStatus> Pane::currentFilterStatus() const
 Core::QuickSearchLine::SearchOptions Pane::currentOptions() const
 {
     Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == 0) {
+    if (w == nullptr) {
         return Core::QuickSearchLine::SearchEveryWhere;
     }
     return w->currentOptions();
@@ -986,7 +988,7 @@ bool Pane::getSelectionStats(Akonadi::Item::List &selectedItems,
                              bool includeCollapsedChildren) const
 {
     Widget *w = static_cast<Widget *>(currentWidget());
-    if (w == Q_NULLPTR) {
+    if (w == nullptr) {
         return false;
     }
 
@@ -1036,7 +1038,7 @@ QItemSelectionModel *Pane::currentItemSelectionModel()
     if (w) {
         return w->view()->selectionModel();
     }
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 void Pane::resetModelStorage()
@@ -1077,7 +1079,7 @@ void Pane::writeConfig(bool restoreSession)
 
     // Delete list before
     const QStringList list = MessageList::MessageListSettings::self()->config()->groupList().filter(QRegularExpression(QStringLiteral("MessageListTab\\d+")));
-    foreach (const QString &group, list) {
+    for (const QString &group : list) {
         MessageList::MessageListSettings::self()->config()->deleteGroup(group);
     }
 
