@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,13 +21,15 @@
 #include <qtestmouse.h>
 #include <KActionCollection>
 
+extern MESSAGEVIEWER_EXPORT bool messageviewer_initialize_database;
 ViewerTest::ViewerTest()
 {
+    messageviewer_initialize_database = false;
 }
 
 void ViewerTest::shouldHaveDefaultValuesOnCreation()
 {
-    MessageViewer::Viewer *viewer = new MessageViewer::Viewer(0, 0, new KActionCollection(this));
+    MessageViewer::Viewer *viewer = new MessageViewer::Viewer(nullptr, nullptr, new KActionCollection(this));
     viewer->show();
     QTest::qWaitForWindowExposed(viewer);
 
@@ -104,7 +106,7 @@ KMime::Message::Ptr createMsg(const char *data)
 
 void ViewerTest::shouldDisplayMessage()
 {
-    MessageViewer::Viewer viewer(0, 0, new KActionCollection(this));
+    MessageViewer::Viewer viewer(nullptr, nullptr, new KActionCollection(this));
     viewer.setMessage(createMsg(s_mail1), MimeTreeParser::Force);
     // not sure what to check, but at least we check it neither crashes nor hangs
     // TODO: retrieve message text and check it
@@ -112,7 +114,7 @@ void ViewerTest::shouldDisplayMessage()
 
 void ViewerTest::shouldSwitchToAnotherMessage()
 {
-    MessageViewer::Viewer viewer(0, 0, new KActionCollection(this));
+    MessageViewer::Viewer viewer(nullptr, nullptr, new KActionCollection(this));
     viewer.setMessage(createMsg(s_mail1), MimeTreeParser::Force);
 
     viewer.setMessage(createMsg(s_mail2), MimeTreeParser::Force);
