@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2016 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2012-2017 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -29,12 +29,12 @@
 using namespace MessageViewer;
 
 ContactDisplayMessageMemento::ContactDisplayMessageMemento(const QString &emailAddress)
-    : QObject(Q_NULLPTR),
+    : QObject(nullptr),
       mForceDisplayTo(Viewer::UseGlobalSetting),
       mEmailAddress(emailAddress),
       mFinished(false),
       mMailAllowToRemoteContent(false),
-      mSearchJob(Q_NULLPTR)
+      mSearchJob(nullptr)
 {
     if (!emailAddress.isEmpty()) {
         mSearchJob = new Akonadi::ContactSearchJob();
@@ -133,8 +133,8 @@ bool ContactDisplayMessageMemento::finished() const
 
 void ContactDisplayMessageMemento::detach()
 {
-    disconnect(this, SIGNAL(update(MimeTreeParser::UpdateMode)), 0, 0);
-    disconnect(this, SIGNAL(changeDisplayMail(Viewer::DisplayFormatMessage,bool)), 0, 0);
+    disconnect(this, SIGNAL(update(MimeTreeParser::UpdateMode)), nullptr, nullptr);
+    disconnect(this, SIGNAL(changeDisplayMail(Viewer::DisplayFormatMessage,bool)), nullptr, nullptr);
 }
 
 bool ContactDisplayMessageMemento::allowToRemoteContent() const
@@ -145,7 +145,7 @@ bool ContactDisplayMessageMemento::allowToRemoteContent() const
 bool ContactDisplayMessageMemento::searchPhoto(const KContacts::AddresseeList &list)
 {
     bool foundPhoto = false;
-    Q_FOREACH (const KContacts::Addressee &addressee, list) {
+    for (const KContacts::Addressee &addressee : list) {
         if (!addressee.photo().isEmpty()) {
             mPhoto = addressee.photo();
             foundPhoto = true;
@@ -168,7 +168,7 @@ QPixmap ContactDisplayMessageMemento::gravatarPixmap() const
 void ContactDisplayMessageMemento::processAddress(const KContacts::Addressee &addressee)
 {
     const QStringList customs = addressee.customs();
-    Q_FOREACH (const QString &custom, customs) {
+    for (const QString &custom : customs) {
         if (custom.contains(QStringLiteral("MailPreferedFormatting"))) {
             const QString value = addressee.custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("MailPreferedFormatting"));
             if (value == QLatin1String("TEXT")) {
