@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -27,7 +27,7 @@ class ScamAttributeTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit ScamAttributeTest(QObject *parent = Q_NULLPTR);
+    explicit ScamAttributeTest(QObject *parent = nullptr);
     ~ScamAttributeTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
