@@ -105,7 +105,7 @@ public:
     * @param actionCollection the action collection where the widget's actions will belong to
     * @param f window flags
     */
-    explicit Viewer(QWidget *parent, QWidget *widget = Q_NULLPTR, KActionCollection *actionCollection = Q_NULLPTR);
+    explicit Viewer(QWidget *parent, QWidget *widget = nullptr, KActionCollection *actionCollection = nullptr);
     virtual ~Viewer();
 
     /**
@@ -278,7 +278,7 @@ public:
     QAction *saveAsAction() const;
     QAction *saveMessageDisplayFormatAction() const;
     QAction *resetMessageDisplayFormatAction() const;
-    QAction *disableEmoticonAction() const;
+    KToggleAction *disableEmoticonAction() const;
     KActionMenu *shareServiceUrlMenu() const;
     HeaderStylePlugin *headerStylePlugin() const;
     void setPluginName(const QString &pluginName);
