@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,7 +31,7 @@ class TestMailWebEngine : public QWidget
 {
     Q_OBJECT
 public:
-    explicit TestMailWebEngine(QWidget *parent = Q_NULLPTR);
+    explicit TestMailWebEngine(QWidget *parent = nullptr);
     ~TestMailWebEngine();
 private Q_SLOTS:
     void slotScrollUp();
