@@ -34,6 +34,7 @@
 
 #include <QSyntaxHighlighter>
 #include <QPlainTextEdit>
+#include <KSyntaxHighlighting/Repository>
 namespace KPIMTextEdit
 {
 class SlideContainer;
@@ -54,22 +55,12 @@ class FindBarSourceView;
  * @author Carsten Pfeiffer <pfeiffer@kde.org>
  */
 class MailSourceViewTextBrowser;
-class MailSourceHighlighter : public QSyntaxHighlighter
-{
-    Q_OBJECT
-public:
-    explicit MailSourceHighlighter(QTextDocument *textdocument)
-        : QSyntaxHighlighter(textdocument)
-    {}
-protected:
-    void highlightBlock(const QString &text) Q_DECL_OVERRIDE;
-};
 
 class MailSourceViewTextBrowserWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit MailSourceViewTextBrowserWidget(QWidget *parent = Q_NULLPTR);
+    explicit MailSourceViewTextBrowserWidget(const QString &syntax, QWidget *parent = nullptr);
 
     void setText(const QString &text);
     void setPlainText(const QString &text);
@@ -77,18 +68,18 @@ public:
     MessageViewer::MailSourceViewTextBrowser *textBrowser() const;
 private:
     void slotFind();
+    KSyntaxHighlighting::Repository mRepo;
     MailSourceViewTextBrowser *mTextBrowser;
     FindBarSourceView *mFindBar;
     KPIMTextEdit::SlideContainer *mSliderContainer;
     KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget;
-
 };
 
 class MailSourceViewTextBrowser: public QPlainTextEdit
 {
     Q_OBJECT
 public:
-    explicit MailSourceViewTextBrowser(KPIMTextEdit::TextToSpeechInterface *textToSpeechInterface, QWidget *parent = Q_NULLPTR);
+    explicit MailSourceViewTextBrowser(KPIMTextEdit::TextToSpeechInterface *textToSpeechInterface, QWidget *parent = nullptr);
 protected:
     void contextMenuEvent(QContextMenuEvent *event) Q_DECL_OVERRIDE;
 Q_SIGNALS:
