@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,7 +21,7 @@ using namespace GpgME;
 using namespace MimeTreeParser;
 
 CryptoBodyPartMemento::CryptoBodyPartMemento()
-    : QObject(0),
+    : QObject(nullptr),
       Interface::BodyPartMemento(),
       m_running(false)
 {
@@ -51,6 +51,6 @@ void CryptoBodyPartMemento::setRunning(bool running)
 
 void CryptoBodyPartMemento::detach()
 {
-    disconnect(this, SIGNAL(update(MimeTreeParser::UpdateMode)), 0, 0);
+    disconnect(this, SIGNAL(update(MimeTreeParser::UpdateMode)), nullptr, nullptr);
 }
 
