@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -41,11 +41,11 @@ void WebEngineManageScript::addScript(QWebEngineProfile *profile, const QString
 {
     if (profile) {
         QWebEngineScript script;
-        QList<QWebEngineScript> collectionScripts = profile->scripts()->findScripts(scriptName);
+        const QList<QWebEngineScript> collectionScripts = profile->scripts()->findScripts(scriptName);
         if (!collectionScripts.isEmpty()) {
             script = collectionScripts.first();
         }
-        Q_FOREACH (const QWebEngineScript &s, collectionScripts) {
+        for (const QWebEngineScript &s : collectionScripts) {
             profile->scripts()->remove(s);
         }
 
